package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````F18``#0```"0@0````0`!30`(``)
M`"@`&P`:``$``'#`>P``P'L``,![```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#,>P``S'L```4`````$```
M`0```+Q]``"\C0``O(T``(P"``"@`@``!@`````0```"````Q'T``,2-``#$
MC0``"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO'T`
M`+R-``"\C0``1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`_*ITW@G]$,2WM5BQ.-]0_`.?\2\$
M````$`````$```!'3E4```````,````"`````````!$```!+````"`````@`
M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"$L```!,````3P``
M`%,```!4````70```%X```!?`````````&$```!B````8P```&0```!E````
M:````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_Y`[9
M<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/JA;&"93\.;:PE#UF>O
MS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)````
M``````````````````````#4$0````````,`"P```````)`````````#`!8`
M$P(`````````````$@```/L``````````````!(```#=`@`````````````2
M````J`(`````````````$@```)H"`````````````!(```"6````````````
M```2````=`$`````````````$@```!$!`````````````!(````!````````
M```````@````DP(`````````````$@```$(!`````````````!(````R`0``
M```````````2````H0(`````````````$@```"0!`````````````!(```#<
M`0`````````````2````$```````````````(````)(!`````````````!(`
M``"P`@`````````````2``````$`````````````$@````<"````````````
M`!(```"W`@`````````````2````+```````````````(````%T"````````
M`````!(```!&```````````````2````8P``````````````%@```&0!````
M`````````!(```!V```````````````2````TP``````````````$@```(<`
M`````````````!(```#Z`0`````````````2````Y`$`````````````$@``
M`+X"`````````````!(```#'`P`````````````2````MP``````````````
M$@```.T"`````````````!$```#5`0`````````````2````!P,`````````
M````$0```!D"`````````````!(````,`@`````````````2````5@$`````
M````````$@```,P!`````````````!(```#D```````````````2````Q0$`
M````````````$@````4!`````````````!(```"S`0`````````````2````
MBP$`````````````$@```)T!`````````````!(```!.`@`````````````2
M````\P$`````````````$@````$"`````````````!(```!<`@``````````
M```2````ZP$`````````````$@```/4"`````````````!(```"B````````
M```````2````*`(`````````````$@```'\!`````````````!(````O`@``
M```````````2````ZP(`````````````$0```'8"`````````````!$```#&
M```````````````1````NP$`````````````$@```$`"`````````````!(`
M``#C`@`````````````2````2P$`````````````$@```#@"````````````
M`!(```!4```````````````2````9`(`````````````$@```'T"````````
M`````!(```#%`@`````````````2````K@$`````````````$@```,P"````
M`````````!(```"$`@`````````````B````(@0``%R0````````$``7`-`#
M``"]+```Q````!(`#0!'!```)28``,0$```2``T`<0(``.$4``"X`0``$@`-
M`$<#```-'0``!````!(`#0!E`P``Z2H``-0!```2``T`^`,``$B0````````
M$``7`&T$```1'0``H`$``!(`#0`M!```2)`````````0`!<`6`,``+$>```8
M````$@`-`'L#``!Q(P``8````!(`#0#<`P``R#D```0````1``\`!@0``!DX
M``#8````$@`-`!$$```I'```/````!(`#0`9!```7)`````````0`!<`0@0`
M`%R0````````$``7`%L$``!%)0``X````!(`#0"$!```T2,``$@````2``T`
MZP,```"0````````$``6`)\#``#)'@``#`$``!(`#0!4!```2)`````````0
M`!8`>@0``$20```$````$0`6`/$#``"9%@```````!(`#0`Y!```I3<``'0`
M```2``T`[0,```"0````````(``6`+4#```U)0``$````!(`#0")`P``91P`
M`*@````2``T`JP,``/$X``"^````$@`-`"$$``!<D````````!``%P",!```
MU1\``)P#```2``T``%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-
M0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES
M7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?
M871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W6%-?9FQA9W,`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D
M97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S
M>7-M86QL;V,`<&5R;%]A;&QO8P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E
M96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR
M`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S=')L96X`<FUD:7(`<F5A9`!S=')S
M='(`;6MD:7(`7U]V9G!R:6YT9E]C:&L`9V5T<&ED`')E861L:6YK`')E86QL
M;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C
M7W-T87)T7VUA:6X`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S=')C
M:'(`;65M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y
M`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`&%B;W)T`'-T<FYC;7``7U]E;G9I
M<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E
M<FPN<V\N-2XS-@!L:6)C+G-O+C8`;&0M;&EN=7@M87)M:&8N<V\N,P!P87)?
M8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/
M3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I
M<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!?7V)S<U]S
M=&%R=%]?`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N9%]?`%]?8G-S7V5N9%]?
M`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T
M80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A
M<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'3$E"0U\R+C,T`$=,24)#
M7S(N,S,```````````(``0`"``(``@`!``$``0`!``(``0`!``(``0`"``$`
M`0`"``(``@`"``$``P`!``$``0`!``$``0`"``(``@`"``$``@`"``0``@`"
M``$``@`!``(``0`"``(``@`"``(``@`#``(``@`!``(``0`"``(``@`!``(`
M`@`"``$``@`!``4``@`"``(``@`"``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`S`P``
M$````"`````4:6D-```$`)D$`````````0`#`"D#```0`````````+21E@8`
M``4`HP0``!````"SD98&```#`*X$```0````%&EI#0```@"9!````````+R-
M```7````P(T``!<```#\CP``%P````20```7````%)```!<````8D```%P``
M`""0```7````))```!<````HD```%P```"R0```7````,)```!<````XD```
M%P```#R0```7````1)```!<```#,CP``%0H``-"/```5"P``U(\``!42``#8
MCP``%1@``-R/```3&P``X(\``!4<``#DCP``%1T``.B/```5)0``[(\``!4G
M``#PCP``%3T``/2/```5/@``^(\``!5*``#8C@``%@,``-R.```6!```X(X`
M`!8%``#DC@``%@8``.B.```6!P``[(X``!8(``#PC@``%@D``/2.```6"P``
M^(X``!8,``#\C@``%@T```"/```6#@``!(\``!8/```(CP``%A````R/```6
M$0``$(\``!83```4CP``%A0``!B/```6%0``'(\``!86```@CP``%A<``"2/
M```6&0``*(\``!8:```LCP``%AX``#"/```6'P``-(\``!8@```XCP``%B$`
M`#R/```6(@``0(\``!8C``!$CP``%B0``$B/```6)@``3(\``!8H``!0CP``
M%BD``%2/```6*@``6(\``!8K``!<CP``%BP``&"/```6+0``9(\``!8N``!H
MCP``%B\``&R/```6,```<(\``!8Q``!TCP``%C(``'B/```6,P``?(\``!8T
M``"`CP``%C4``(2/```6-@``B(\``!8W``",CP``%C@``)"/```6.0``E(\`
M`!8Z``"8CP``%CL``)R/```6/P``H(\``!9```"DCP``%D$``*B/```60@``
MK(\``!9#``"PCP``%D0``+2/```610``N(\``!9&``"\CP``%D<``,"/```6
M2```Q(\``!9)``#(CP``%DH```A`+>D[`0#K"("]Z`3@+>4$X)_E#N"/X`CP
MON7<?````,:/X@?*C.+<_+SE`,:/X@?*C.+4_+SE`,:/X@?*C.+,_+SE`,:/
MX@?*C.+$_+SE`,:/X@?*C.*\_+SE`,:/X@?*C.*T_+SE`,:/X@?*C.*L_+SE
M`,:/X@?*C.*D_+SE`,:/X@?*C.*<_+SE`,:/X@?*C.*4_+SE`,:/X@?*C.*,
M_+SE`,:/X@?*C.*$_+SE`,:/X@?*C.)\_+SE`,:/X@?*C.)T_+SE`,:/X@?*
MC.)L_+SE`,:/X@?*C.)D_+SE>$?]YP#&C^('RHSB6/R\Y0#&C^('RHSB4/R\
MY0#&C^('RHSB2/R\Y0#&C^('RHSB0/R\Y0#&C^('RHSB./R\Y0#&C^('RHSB
M,/R\Y0#&C^('RHSB*/R\Y0#&C^('RHSB(/R\Y0#&C^('RHSB&/R\Y0#&C^('
MRHSB$/R\Y0#&C^('RHSB"/R\Y0#&C^('RHSB`/R\Y0#&C^('RHSB^/N\Y0#&
MC^('RHSB\/N\Y0#&C^('RHSBZ/N\Y0#&C^('RHSBX/N\Y0#&C^('RHSBV/N\
MY0#&C^('RHSBT/N\Y7A'_><`QH_B!\J,XL3[O.4`QH_B!\J,XKS[O.4`QH_B
M!\J,XK3[O.4`QH_B!\J,XJS[O.4`QH_B!\J,XJ3[O.4`QH_B!\J,XIS[O.4`
MQH_B!\J,XI3[O.4`QH_B!\J,XHS[O.4`QH_B!\J,XH3[O.4`QH_B!\J,XGS[
MO.5X1_WG`,:/X@?*C.)P^[SE`,:/X@?*C.)H^[SE`,:/X@?*C.)@^[SE`,:/
MX@?*C.)8^[SE`,:/X@?*C.)0^[SE`,:/X@?*C.)(^[SE`,:/X@?*C.)`^[SE
M`,:/X@?*C.(X^[SE>$?]YP#&C^('RHSB+/N\Y0#&C^('RHSB)/N\Y0#&C^('
MRHSB'/N\Y0#&C^('RHSB%/N\Y0#&C^('RHSB#/N\Y0#&C^('RHSB!/N\Y0#&
MC^('RHSB_/J\Y0#&C^('RHSB]/J\Y0#&C^('RHSB[/J\Y7"U6TV*L%M+?41;
M3,WI!A`&J062!Z@%JGQ$ZU@;:`F33_```__WPN]42E5+HE@#DA%&XU@$DQA&
M`O!*^E%+XU@<>``L8]`=[G`O1TL'G7M$&V@H'0,UL/&`3])8DOC&,T/P`P."
M^,8S=-*``/_W<N]%2@:<`T9Z1$1)>4108")H&F!#2@>8>D3:8$)*`2@):'I$
MF6!:8%_=(1T$ZX`.`_$,#%'X!$M,^`1/CD7YT0,P.4P`(0"1*D9\1$/X(!`W
M2>!H>43_]TKN`"@QT#1-"*Y]1.AH__?:[@1&,D@Q1GA$`/#H^$"S,$M[1-AH
M__<8[O_WBNXM2A]+>D336!IH"9M:0$_P``,LT2!&"K!PO?_W5NXG2GI$T&``
ML__W@NX32QWN<"][1!MHTUB#^'M'C.?@:/_W)N[)YZAH$+$!\$[[T><<2#%&
M>$0`\+3XJ&``*,G0\^?_]Z;N!""IYP$@__<^[__WP.X`OZIZ``#4>0``X'D`
M`"`!``#0>0````$``!@!```H`0``\GH``.9Z```6*```""@``+!Z```7!@``
MF'H``%XE``"`>@``\'@``%1Z``"2)```3_``"T_P``X"O&I&!+0!M-_X&*`%
MHYI$3_```PBT!$A:^```__?L[O_WI.T(>```,`$``!0PG^44()_E`S"/X`(@
MD^<``%+C'O\O`=?^_^KP=P``!`$```9(!TL'2GA$>T1Z1(-"`]`%2]-8`[$8
M1W!'`+].>0``3'D``,YW```(`0``"$@)2WA$"4I[1!L:>D39#P'KHP%)$`/0
M!4O36`.Q&$=P1P"_)'D``"!Y``"@=P``#`$```BU"DL*2GM$>D0;>&NY"4O3
M6".Q"$M[1!AH__>T[O_WO_\&2P$B>T0:<`B][G@``'!W```L`0``FG@``,YX
M``#$YP"_+>GX0X!&'TM[1``H-M`>2IM8T_@`D+GQ``\QT`5X#T8`+1B_/2T4
MOP$E`"43T=GX`$!LL4Y&*D9!1B!&__=([A"Y8UT]*Q#05O@$3P`L\M$@1KWH
M^(,%1A7X`3\`*QB_/2OYT:7K"`7AYZ;K"08!-2Q$MA`^8"!&O>CX@P1&Y^=,
M1N7G+'<``!P!```72AA+>D00M01&G+#36&E&&V@;DT_P``/_]]SMH+D$FP/T
M<$.S]2!/&+^S]8!/#=`-2@Q+>D336!IH&YM:0$_P``,+T1RP$+T`(/'G`B$@
M1O_W+NVP^H#P0`GIY__WHNVD=@``(`$``'1V```V2C=+>D3PM9^PTU@;:!V3
M3_```Q"Q`W@$1ENY,4HP2WI$TU@::!V;6D!/\``#4]$?L/"]__>J[`5&`"CN
MT"A&__>^[0`H-M##?`#Q$P8N*P+1<W@`*_+0PWPN*S+0($;_]P[M!T8P1O_W
M"NTX1`(P__=<[1Q+3_#_,@$A>T0!E@"4!D;_]Z+M`JDP1O_WX.P!,#!&!=`&
MFP/T<$.S]8!/%]#_]_3L,$;_]\#L*$;_]XCM`"C(T2A&__<8[2!&__=.[:OG
M<W@N*\G1LW@`*[;0Q>?_]Y7_YN?_]R[M.'8``"`!```<=@``4"$``%A*64MZ
M1"WI\$<,1H*P!4;36-_X6($;:`&33_```PMX^$0]*PB_`30@1O_WM.QI1@9&
M*$;_]_+^@48`*%30__>J[(9"1]E*2P"?6/@#@+\`*W@`*QB_/2L4OP$C`",'
MT"M&$_@!+P`J&+\]*OG16QNP'-CX`&`81/_WXNSP4>BQV/@`,"A&V5D0^`$[
M"W`]*QB_`"L)T$H<$/@!.Q%&`O@!.STK&+\`*_;1"D8](PMP%/@!.P+X`3\`
M*_G1+4HJ2WI$TU@::`&;6D!/\``#1M$"L+WH\(<)\?\Y%/@!.PGX`3\`*_G1
MZ><A2UCX`X#8^`!P.VB#LSM&4_@$+TE&"?$!"0`J^-$#,8D`&TIZ1!-HN[D(
M1@$C$V#_]Y+L@D8`*,S0.49/ZHD'.D;_]Z[LR/@`H,WX`)`)\0$)`"-*^"DP
MAN<X1O_WX.R"1LCX````*+303^J)!^SGF48((=7G__=V[`"_3'4``"`!```P
M=0``'`$``)!T``#$=0``+>GP00]&+$DL2ZWU@%UY1(*P!D8-]8!0!#`-\00(
MRUA`]O]R048;:`-@3_```R1(>$3_]XSL!!X'W0*M8QX%ZP,,'/@$+.JYV[D9
M2QWN<`\Z1C%&>T0;:,!8__>:ZQE*#?6`415+!#%Z1--8&F@+:%I`3_```QC1
M#?6`70*PO>CP@1Q&(D8O(4!&__>2[``HV]`(2!WN<%\C1D)&>$0`:#%&*%C_
M]]#KV>?_]Q+L`+^0=```2'0``,9S```@`0``/!\``&QS```PM1WN<$\22@])
MA;`12'I$>40):!!+`"5[1!)88%@/20.2>43_]TCL"$D-2WE$"6@,2GM$>D1@
M6`M)`95Y1`"3__=ZZP6P,+T,=```\',``/YR```4`0``1%\``)(>``"&(0``
M]0X``)0>```*2H*P"DD=[G#/>D0&2`E+>$0`:%)8>T0'25SX``!Y1`&2`K#_
M]Q"\H',``)9R```4`0``VEX``"H>```D2G"U)$MZ1*WU`%V&L`WU`%$#K--8
M%#$-]8!6&V@+8$_P``/_]\[K'$H!(1Q+$#9Z1,WI``)[1"!&0?(!`O_WVNL@
M1D_T@%(Q1O_WR.L$'KB_`"4*VV`<__=\ZP5&*+$B1C%&__<LZP`C*U4-2@WU
M`%$)2Q0Q>D336!IH"VA:0$_P``,$T2A&#?4`70:P<+W_]V;K7G(``"`!```<
M'@``"AX``.YQ``#_]ZJ_6THMZ?!/!D9:2WI$K?6$78&P64@-]8-5#?$0"--8
M#$9X1$%&'#4;:"M@3_```__W*?TO(05&,$;_]X3JP+%/2#%&>$3_]Q#^,$9-
M2@WU@U%(2QPQ>D336!IH"VA:0$_P``-`\(.`#?6$70&PO>CPCR!&__<(ZT-)
M>43_]RCK!$8`*-S0(W@-\8`*W_C\D*KQ!`?Y1``K2-`EL2%&*$;_]X#KN+,@
M1O_WJNI#'B-$@T:<0CZ_(Q@`(6`<`],*X)A"&7`#T!/X`2TO*OC0($;_]Y;J
M@T8P1O_WDNI81`$PL/6`7ZS2*4@!(4M&3_2`4GA$`)3-Z0$&.$;_]R;K048X
M1O_W9.HPN5KX8#P#]'!#L_4`3Q?0'DD`('E$__?8Z@1&`"B,T"-X`"NVT=6Q
M*W@N*P30&$Q/\`$+?$3+YVMX`"OHT/;G`2$X1O_W.NH`*.'1$4@Y1GA$__>'
M_3A&__>2ZG/G#DQ/\`$+?$2SY__WHNJN<0``(`$``(@=``!R'0``9'$``$P=
M```V'0``XAP``*P<``!L'```8!P``#P<```0M2\A!$;_]^SI`+%$'"!&O>@0
M0/_W9+H[2O"U.TMZ1*WU@%V#L`WU@%'36`0Q&V@+8$_P``,`*#S0`W@%1@`K
M.-#_]PSJ0AP$1K+U@%]'V`&O*48X1O_W#NIC'CM$GT(+TC@9#?$%`@`A`N"0
M0@%P`]`0^`$]+ROXT"\A.$;_][#I>+.X0H2_`",#<#A&__<JZA]*#?6`41Q+
M!#%Z1--8&F@+:%I`3_```RO1#?6`70.P\+T72@WU@%$42P0Q>D336!IH"VA:
M0$_P``,:T1)(>$0-]8!=`["]Z/!`__<`N@`@UN<-2@WU@%$(2P0Q>D336!IH
M"VA:0$_P``,"T0A(>$3FY__W!NKZ;P``(`$``'QO``!:;P``-!L``"IO```$
M&P``S$K-2WI$<+7,3H*PS$W36'Y$;$9]1!MH`9-/\``#(48P1O_WS?NPL<9+
M`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>W^P`HZ-&\
M3GY$(48P1O_WK_NPL;=+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J
M^M$A1C!&__>9^P`HZ-&N3GY$(48P1O_WD?NPL:A+`)CK6!EH`>N``UIH0?@@
M(``J[]`$,UIH0_@$*P`J^M$A1C!&__=[^P`HZ-&@3GY$(48P1O_W<_NPL9E+
M`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__==^P`HZ-&2
M3GY$(48P1O_W5?NPL8I+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J
M^M$A1C!&__<_^P`HZ-&$3GY$(48P1O_W-_NPL7M+`)CK6!EH`>N``UIH0?@@
M(``J[]`$,UIH0_@$*P`J^M$A1C!&__<A^P`HZ-%V3GY$(48P1O_W&?NPL6Q+
M`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__<#^P`HZ-%H
M3GY$(48P1O_W^_JPL5U+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J
M^M$A1C!&__?E^@`HZ-%:3GY$(48P1O_WW?JPL4Y+`)CK6!EH`>N``UIH0?@@
M(``J[]`$,UIH0_@$*P`J^M$A1C!&__?'^@`HZ-%,3GY$(48P1O_WO_JPL3]+
M`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>I^@`HZ-$^
M3GY$(48P1O_WH?JPL3!+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J
M^M$A1C!&__>+^@`HZ-$P2"%&>$3_]X3Z`488L2U(>$3_]W#[+$@A1GA$__=Y
M^@%&&+$J2'A$__=E^RE((49X1/_W;OH!1K"Q)DAX1/_W6OLE2A%+>D336!IH
M`9M:0$_P``,5T2%)(DAY1'A$`K"]Z'!`__='NQ]((49X1/_W4/H!1@`HY-`<
M2'A$__<[^]_G__=>Z/!N```@`0```!L``.!N```<`0``Q!H``)`:``!@&@``
M+!H````:``!@&0``E!D``&09```T&0``?!@``,88``"B&```Q!@``,P8``#.
M&```^A<```!L``#(&```+A@``*(8```L&```$TH42WI$`+432(.PTUAX1&E&
M&V@!DT_P``/_]P/Z0+$`>``H&+\P*`R_`2``((#P`0`*2@=+>D336!IH`9M:
M0$_P``,"T0.P7?@$^__W`NA4:P``(`$``*H7```B:P``#[3?^#3``+4,2OQ$
M@[`$JPM)#$A<^`(@>402:`&23_```E/X!"L`DPA8`2$`:/[WJN__(/_W6NCN
M:@``(`$``.!J```D`0``+>GP1P(A/TRM]8`]`"*&L'Q$#?6`-0`C%#6`1@"1
M.DEA6`EH*6!/\``!_O>T[P$X8?$`!_H7@.H"`YL:F[)30)L:8NL"`L8:9^L"
M!P`O2]M/\`@)P/(!"0.M`"$R1CM&0$8`D?[WEN^Q\?\_"+^P\?\_0=!*1BE&
M0$;^]QCO0QPVT`<H)MD(."P8(]+?^'R@^D0"X`$\K$(<TP@B448@1O[WM.X`
M*/719!N@&4?KY'$72@WU@#042Q0T>D336!IH(VA:0$_P``,:T0WU@#T&L+WH
M\(>V]8`V9_$`![?Q_S\(OQ;U@#^XT4_P_S`!1M_G"$AX1/_W8/\'2'A$__=<
M__[W5.^@:@``(`$``%QK``#V:0``KA8``)86```(M?[WN.[^]_KN`+$`:`B]
M+DHO2WI$\+4N3H>P!4;36'Y$!*DP1AMH!9-/\``#__<7^1"Q`W@$1HNY)THD
M2WI$TU@::`6;6D!/\``#/-$C2"E&>$0'L+WH\$#_]_.Y*4;^]^3N6+$>2AE+
M>D336!IH!9M:0$_P``,FT0>P\+TH1O[WJNX'1B!&_O>F[CA$`C#^]_CN$TM/
M\/\R`2%[1`&3$4L"E`1&>T0`E?[W/.\/2@=+>D336!IH!9M:0$_P``,$OR%&
M,$;%T/[WXNZ`:0``(`$``'`6``!6:0``/A8``"II```$%0``_A0``.)H``#?
M^#P4+>GP3X)&W_@X5-_X."1Y1'U$O;`%\0P#!?$8#"*O**R*6"9&,#4-\90)
M$F@[DD_P``+?^!2TD^@'`(?H!P`-\2`(O.@/``_&^T2<Z`,`AN@#`)7H!P")
MZ`<`_$A!1GA$__>$^""Q`W@%1@`K0/!I@?[W!N[^]TCN`"@`\)V`!F@`+@#P
MF8`P1O[W+.Y```$P_O=^[C%X!48'D'FQW_BPD_E$*$8`D4M&`2%/\/\R`C7^
M][[N%O@!'P`I\M'E2'A$`N!4^`0/B+%!1O_W3_@%1@`H]M`#>``K\]#_]XWX
M`"COT"A&_O="[@1&B+E7^`1+=+$C>``K`/`/@2!&__=\^``H\]`@1O[W,NX$
M1@`H[=`@1O[WZ.T'G09&*$;^]^+M!D0&\@1&,$;^]S+NRDL'1D_P_S)[1`*3
MR$L!(0.5>T0!D\=+`)1[1/[W<NY/].!Q.$;^]SSM`3`%T?[WHNX!:!$I0/#@
M@$%&.$;^]S#N!48`*#G0NTG:^``PNTI;^`$`>D0`EP$A`&C^]P[N`":W2JQ+
M>D336!IH.YM:0$_P``-`\$:!,$8]L+WH\(_^]][M!D8`*$#PLH!9^`0+6+%!
M1O[WU/\`*/?0`W@`*^[16?@$"P`H\]&F3@T@_O?:[5,A!49^1`>06><,FP/T
M<$.S]8!/O]$.G/[W1.V$0KK1#)O#\P@#L_7@?[31,$;^]\#M!D:82$%&>$3^
M]ZC_`48`*`#PH8#:^```__=>^H%&`"@`\)F`2$;^]U;M!$8#*`_9C4D$.$A$
M>43^]Q[N0+D$+`#PV8!,1!3X!3PO*P#PTX"&2$%&>$3^]X'_(+$#>#`K&+\`
M*P;1`"%(1O[W4NT$1@`H<]%^27](>43?^/RA>$3?^/B1__=<^-_X]('^][#M
M?$M/\/\R`2%[1`.3>DOZ1`"7^41[1,WI`3!X2S!&^$1[1/[WMNT3X/[WZNT#
M:!$K%M'^]Y;M`36$1E-&(D8!(3!&S>D#6<WI`8P`E_[WH.U/].!Q,$;^]VKL
M!$9#'./0.$;^]\;L9D@Q1GA$__<@^#!&__<#_CKG'$;YYO[WXNQ```$PM.9/
M2MKX`#!;^`(`S>D`<0$A6TH`:'I$_O<T[23G__?K_5A*/DMZ1--8&F@[FUI`
M3_```VK1*$8]L+WH\$_^]P&]VO@`D&/G__=`_8!&L?$`"87;L/$*`D_P``II
M\0`#($8-\;@+S?@`H/[W^NP&(EE&($;^]X#L!BA)T2Z:3_2&0\3R03.:0G_T
M:J^[^`0@1/)(4YI"?_1CK[CQ,@(@1FGQ``,PK<WX`*#^]]KL($8H(BE&_O=@
M["@H*=$R2P$A,DHP1GM$`9,Q2WI$`I4#DGM$3_#_,@"7C?CHH/[W%NU\Y]KX
M!$``+#_T**\@1O[W:.P#*'_V(J\F200X($1Y1/[W,.T`*`B_H487Y_[WM.PA
M2'A$__>V_))H``#,:0``(`$``%AH```R%```%!4``(X4``"4%```>A,``'84
M```D`0``C!0```YG``#*$P``2A0``"(4``"<$@``]!(``'(2``#V$P``FA0`
M`/H1``"D%```!!(``-03``"&$0``EA(``%9E``#0$```7A,``)`2``!.$@``
M0A(``&1)94IY1'"U6DN"L!WN<$^*6&Y&84@Q1A)H`9)/\``">T0;:'A$Y5B5
M^&@PA?AI,/[W//X0L0-X,2M\T/_W5OI-2WM$&VCE6%5)*$8#(P$B>43^]YCK
M!49PL0)I1TM[1!MH$6A/2N!8>D3^]YCK*VD9:(MH6P)KU$%)`R,!(GE$"6A@
M6$A)>43^]WSK!49XL49(,49X1/[W"?X"1@`H3M`X2REI>T0;:`EHX%C^]W;K
M-4L!(CY)>T0;:'E$Y5@H1O[W0NL[2@%&*$9Z1#I-_O=FZRY+.4A]1'M$&V@`
M(GA$,4;C6(/X:2#^]^#]!$:H8+"Q3_3@<2!&_O<(ZT(<`T81*!B_`2HLV"U*
M(TMZ1--8&F@!FUI`3_```R#1`K!PO6AH__<+_01&J&``*.'1)4AX1/[W`.Q#
M>``KA=!^YR)+*FE[1!!H6V@9:/[W7_^OYP]+>T0;:.!8_O>NZXSG_O>^ZQI)
M(D8:2'E$>$1):`EH_O?@Z]!D``"N9```DF0``')D``!,9```.F0``!AD``">
M8P``W&,``"`!````$```J!$``)01``!^$0``2`\``$X1``!6$0``BF0``/(.
M``#48@``^!```!YD``#X8P``XA```"I**TMZ1#"U!4:#L--8&V@!DT_P``/_
M]_GX+R$$1O[WVNH`L40<($;^]U;K!$8A2&E&>$3^]U#]<+$#>#`K&+\`*PR_
M`2,`(X/P`0,`+0R_`",#\`$#6[D72A5+>D336!IH`9M:0$_P``,<T0.P,+TK
M>``K\-`1200B($9Y1/[WE.L`*.C1#DH)2WI$TU@::`&;6D!/\``#!=$H1@.P
MO>@P0/[WE;W^]S#K`+\(8@``(`$``#H.``"P80``N`X``()A```MZ?!/`T;?
M^!!*K?4K?0/Q@`??^`@Z?$0(J0`F`I`*1D`PO$;C6!MHJ9-/\``#4.D"=%9@
MUF`0,C^Z0O@0?",*)0(#]']#"#!#ZA1C!?1_!4/J!&-@14/J!0-"^`@\YM'=
MZ2*""JPFFPWQB`D`DR2H)JT!]0)S`Y`@1@25S>D%00UHS?@<D)%&W?B4X-WX
MG,`)G]WX++`DGMWX**``F0&3`>"21IM&`)$`(]#I#A10^`@O0V=10('J"`&P
M1D-H:4``GE5&7$"$Z@D$\49\0.9&3^K1?$D83.I$#`&<0>H,`5]&3_``#(1"
M`6?:T0.;`IC=Z05!'6@$F]#I`7L;:`.3T.D#.D_JFP[0^`#`"F@A:$[J@WZ$
M:4?VF1/%]H(C`)0$:M(83^K<8`&40.I'$!(9`)Q`ZDP0W?@<D((8BNH$`$[J
MBWX`Z@L`W?@P@&!`V?@`8!(83^J<"8KJ#@#)&$GJAWD`Z@P`2>J,>0D9@.H*
M``Z?"!B.Z@D!&.L#"!%``.OR8!CK"@B!Z@X!3^JR`ACK`0'_&!?K#@@!Z_!G
MB>H"`=WX0.`!0$_JL`"!Z@D!&.L!`1[K`PX>ZPD)`>OW;H+J``'=^$B`.4!/
MZK<'44`9ZP$!&.L#"!CK`@F`Z@<"W?A0@`+J#@(!Z_YA0D!/ZKX.&>L"`ACK
M`P@8ZP`)`NOQ8(?J#@+=^%B`"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!
M`MWX8(`"0$_JL`""Z@X"&>L"`ACK`P@8ZPX)`NOW;H'J``+=^&B`.D!/ZK<'
M2D`9ZP("&.L#"!CK`0D"Z_YA@.H'`MWX<(`"Z@X"3^J^#D)`&>L"`ACK`P@8
MZP`)`NOQ8(?J#@+=^'B`"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX
M@(`"0$_JL`""Z@X"`YP9ZP("&.L#"!CK#@X"Z_=H@>H``CI`3^JW!TI`'NL"
M`O88=AB`Z@<!`>H(`0+K^&)!0$_JN`AQ&.T8+1@!Z_)@A^H(`1%`3^JR`HCJ
M`@9Y0&D8!D`HG>08`>OP88;J"`9/ZK``Y!FD&8+J``?M&`]`%>L(!BJ=!.OQ
M9%=`3^JQ`?89@.H!#NT8KQ@.Z@0.+)U/ZK0"CNH`#@;K]&87ZPX$@>H"!^T8
M-T`M&"Z83T`$Z_9D[QE/ZK8&PQ@PG5L8@NH&`2%`!^OT;E%`3^JT!%@83O:A
M,\;VV6,RF17K`P@`Z_Y@&.L""(;J!`*"Z@X"3^J^!1CK`@B$Z@4.RA@TGPCK
M\&&.Z@`.DAE/ZK``$NL.`C:>_QB%Z@`.`NOQ8H[J`0X\&4_JL0$4ZPX$.)_V
M&(#J`0X$Z_)DCNH"#G493^JR`A7K#@4ZGH'J`@[_&([J!`X_&`7K]&`7ZPX'
M3^JT!!;K`PX\G1[K`0X'Z_!A@NH$!T=`3^JP`![K!P[O&#Z>OQ@.Z_%BA.H`
M#H[J`0Y/ZK$!%^L.!Q;K`PY`G1[K!`X'Z_)D@.H!!U=`3^JR`A[K!P[O&$*>
M/Q@.Z_1@@>H"#H[J!`Y/ZK0$%^L.!T2=@NH$#O88!^OP9X[J``YV&$_JL``6
MZPX&1IF$Z@`.[1@&Z_=FCNH'#JT83^JW!Q7K#@5(FLD8@.H'#@7K]F6.Z@8.
M#!E/ZK8&%.L.!$J9TAB'Z@8.!.OU9([J!0X0&$_JM040ZPX`3)J&Z@4.R1@`
MZ_1@CNH$#LD93^JT!!'K#@%.GX7J!`[2&`'K\&&.Z@`.DAE/ZK``$NL.`E">
M_QB$Z@`.`NOQ8H[J`0Y]&4_JL0$5ZPX%4I_V&(#J`0Z.Z@(.-!D4ZPX$!>OR
M9A?K`PY/ZK("5)T>ZP`.@>H"``3K]F1P0![K``Y/ZK8`[1B"Z@`&:1A6G69`
M#NOT;HD93^JT!.L86)V;&(#J!`*"Z@X"3^J^!YH82_;<0\CV&W,!Z_YA[1A$
MZ@<.6IXH&`[J`0X$Z@<%3NH%#@+K\6(0ZPX.3^JQ`?`87)T`&4?J`00.Z_)F
M%$`'Z@$.3^JR`D3J#@0!Z@(()!CM&$'J`@`5ZP<.,$`$Z_9E7IQ`Z@@`3^JV
M!A#K#@[@&`[K]61`&$+J!@$"Z@8.*4!@GT'J#@%/ZK4%"1@!Z_1@_QA&Z@4!
M!NH%#KH8(4!BGT_JM`1!Z@X!!>H$"(D8_QA%Z@0"%^L&#@)`9)\!Z_!A0NH(
M`D_JL``2ZPX"_Q@$Z@`.?1D"Z_%G1.H``F:>"D!/ZK$!0NH.`MWXH.%5&?(8
M$AE`Z@$$3^JW!@7K]V4\0`#J`0<\0T'J!@>B&![K`P0D&`'J!@YJF"]``NOU
M8D?J#@=/ZK4%/!E&Z@4'P!@$Z_)D!NH%#D`8%T!/ZK(!;)I'Z@X'/QA%Z@$`
MTA@@0)(9!^OT9@7J`0=/ZK0$.$-!Z@0'@!ANF@'J!`XW0-(8`.OV8%49<)I'
MZ@X'3^JV!G\9TAA5&`?K\&%$Z@8'!.H&#G*:!T!'Z@X'3^JP`'T9TA@2&4;J
M``0&Z@`'#$`\0P7K\66D&'2:3^JQ`03K]632&$#J`0<`Z@$.EADO0'::1^H.
M!T_JM06_&=(8%A@'Z_1@0>H%!P'J!0YXFB=`1^H.!T_JM`2_&47J!`;2&`9`
M4A@'Z_!A!>H$!T_JL``^0P*?MA@`(@3J``X&Z_%F>F#Z8'J:TAA5&0`B>F'Z
M843J``=\F@]`1^H.!T_JL0%_&=(80.H!!0?K]F<2ZP0.-4!/ZK8$?IH`Z@$&
M-4,!Z@0&%>L.!=,8&QA!Z@0`.$"`FC!#!>OW9<`83/+6$\SV8B-/ZK<'UAB"
MFG88A.H'`6E``.OU8'883^JU!=(8A^H%`109A)I!0`;K\&9D&$_JL`#2&(7J
M``'7&8::!.OV9'%`?QA/ZK8&T1B(FDD9!^OT98#J!@=G0$_JM`3)&=<8/QB*
MFH;J!``!Z_5A:$!/ZK4%/QC0&(`9C)H'Z_%FA.H%!T]`3^JQ`<`9UQ@_&8Z:
MA>H!!`#K]F!T0#\93^JV!-88D)IV&0?K\&6!Z@0'1T!/ZK``]AG7&'\8DIH&
MZ_5AA.H`!FY`3^JU!;\9UA@V&92:!^OQ9(#J!0=/0$_JL0'V&=<8/QB6F@;K
M]&"%Z@$&9D!/ZK0$OQG6&'89F)H'Z_!E@>H$!T=`3^JP`/89UQA_&)J:!NOU
M883J``9N0$_JM06_&=88-AF<F@?K\62`Z@4'3T!/ZK$!]AG7&#\8GIH&Z_1@
MA>H!!F9`3^JT!+\9UAAV&:":!^OP98'J!`='0$_JL`#V&=(85Q@&Z_5AHIJ$
MZ@`&;D!/ZK4%OQG2&!89!^OQ9(#J!0>DFD]`3^JQ`?<9`IX'Z_1GTA@0&`KK
MMP(R8:::A>H!!F9`3^JT!(`9TQB!Z@0"`.OW8'I`$^L,`P*?6QF;&!#K"P(#
MZ_!C`)@[8`&;)!BZ8`Q*R1@`(WMB"4MZ1+QA.6+36!IHJ9M:0$_P``,#T0WU
M*WV]Z/"/_?<8[@"_,F$``"`!``!25P``"+6`(/WW!NZ?[0Y[`"*"9X#M`'N?
M[0U[@.T">Y_M#7N`[01[G^T->X#M!GN?[0U[@.T(>Y_M#7N`[0I[@.T,>PB]
M`+\!(T5G`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,`````````
M```````MZ?A#!4861H!J`",,1O<7U>D,(0#KQ@R$1>AJ<^L```+2`3)!\0`!
MJ&\%\3@(Q>D*PW,/0^K'`YL8*V-!ZU=Q:6.`NS\N1=VF\4`)3^J9%G<<!.N'
M%R%&0T8$\4`.T?@`P!`Q4?@,3!`S4?@(#%'X!"QQ14/X$,Q#^`Q,0_@(#$/X
M!"SKT0Q&*$;_]VWZO$+AT:GKAA8R1CE&0$;]]S;MKF>]Z/B#P/%`!P7Q.`BW
M0D!$J+\W1B%&.D;]]RCMJV\[1*MG0"OLT2A&]AL\1/_W2_JWYR=&WN<MZ?!!
M`?$X!PQ&BVH%1@IKD_J#^,/SQ0,6NED<@"(X*?I41=W!\4`">!@`(?WWK.P@
M1O_W+?HX1C@B`"']]Z3L($;$Z1QH__<C^N-X*W`@1F.(:W`C:!L*JW`C:.MP
MXWHK<6.):W&C:!L*JW&C:.MQXWPK<F.*:W(C:1L*JW(C:>MRXWXK<V.+:W.C
M:1L*JW.C:>MSE/@C,"MT8XQK="-J&PJK="-JZW2]Z/!!_?>*O'@8P?$X`@`A
M_?=F[,#G`+\"2WM$&VC]]RF]`+].5@``"$`MZ0B`O>@!``(`/@```$$````,
M````00```!$```!!````)P```$$````V````00````,```!!````!@```$$`
M```5````00````\```!!````#@```$$````F````00```!,```!!````*0``
M`$$````"````00```!D```!!````"@```$$````+````00``````````````
M)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X
M90`N````4$%27U1%35``````4$%27U!23T=.04U%`````#H````E<R5S)7,`
M`"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$
M14)51P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,
M3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@`````Q````;'-E96L@9F%I;&5D`````')E860@9F%I
M;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`
M````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@````!S
M:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S
M)7-T96UP+25U+25U)7,`````&````'!E<FP`````,````%!!4CHZ4&%C:V5R
M.CI615)324].`````#$N,#4Y````56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%53
M15(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M<`````!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA
M;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*
M)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N
M86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]
M"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N
M:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F
M:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S
M:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N
M:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`[
M"G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!
M1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@
M/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I
M>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@
M0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D
M=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE
M;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B
M.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*
M0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S
M*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP
M*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!]
M(ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD[
M"DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE
M<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#
M86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U
M<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#
M.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@
M*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S
M=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S
M="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@
M)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D
M8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B
M("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME
M<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R
M("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T
M7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B
M3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E
M="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E
M<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H
M)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U
M9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM
M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@
M/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D
M*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U
M*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB
M=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I]
M.PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U
M9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L
M92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM
M>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S
M<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[
M)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[
M4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E
M871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN
M="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@[
M"GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R
M8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N
M86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*
M9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@
M)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER
M92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O
M<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I
M;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE
M;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L
M<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U
M<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE
M;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;
M3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O
M9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@
M*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I
M;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@
M('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*
M;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@
M)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O
M=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET
M92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*
M96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E
M<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG
M="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G
M*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@
M)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0
M)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D
M9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@
M)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@
M86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*
M)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS
M.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U
M9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@
M<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@
M)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@
M<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D
M92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@
M)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@
M)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=
M.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M
M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"![
M"B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L
M:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN
M8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E
M>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F
M:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O
M*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0[
M"GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@
M*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D
M9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]
M"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[
M)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,
M12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE
M*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E
M;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E
M9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M
M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A
M<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL
M94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE
M=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS
M92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG
M97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I
M;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^
M:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE
M+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@
M*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M
M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@
M/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C
M:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC
M:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE
M9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE
M.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H
M:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E
M;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D
M.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R
M;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R
M-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I
M.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@
M)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N
M86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T
M<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA
M;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R
M(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@
M(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M
M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@
M70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&
M:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E
M<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U
M;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS
M=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN
M84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q
M=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L
M.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA
M;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI
M8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$[
M"G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2
M.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T
M97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E
M<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E
M(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER
M92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H
M"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@
M=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]
M("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D
M<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%
M3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L
M<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC
M7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L
M("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#
M04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<
M,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@
M)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!
M0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@
M)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER
M(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE
M7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER
M(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T
M;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?
M87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F
M=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL
M;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H
M.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F
M:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?
M97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]
M"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[
M7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE
M('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@
M*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N
M86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H
M9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F
M:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D
M8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S
M>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%2
M7T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT[
M"GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G
M9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?
M7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@
M0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@
M<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M
M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P
M87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A
M;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL
M92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R
M;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)2
M3U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P````!#04-(10``/@```$$````,
M````00```!$```!!````)P```$$````V````00````,```!!````!@```$$`
M```5````00````\```!!````#@```$$````F````00```!,```!!````*0``
M`$$````"````00```!D```!!````"@```$$````+````00``````````````
MV)K_?P$`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````)$7``!1%P```0```!D#```!````*0,```$````S`P``
M#````-01```-````P#D``!D```"\C0``&P````0````:````P(T``!P````$
M````]?[_;[0!```%````,`D```8```"@`@``"@```+D$```+````$````!4`
M`````````P```,R.```"````Z`$``!0````1````%P```.P/```1````'`\`
M`!(```#0````$P````@````>````"````/O__V\!```(_O__;[P.``#___]O
M`@```/#__V_J#0``^O__;PX`````````````````````````````````````
M````````````````````Q(T`````````````X!$``.`1``#@$0``X!$``.`1
M``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$`
M`.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``
MX!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@
M$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1
M``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$`
M````````````````````````````````````````````````````````````
M`````.$4````````!)````I005(N<&T*`````*0]``"X.@```````'@[``!\
M.P``F#T``,`Z``"@/0```````(0]``",/0```````*P]``!'0T,Z("A$96)I
M86X@,3,N,BXP+3(I(#$S+C(N,`!!,@```&%E86)I``$H````!3<M00`&"@=!
M"`$)`@H$$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-
M+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S
M``````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``&0```````````````0`````````3````!P``
M``(```!P`0``<`$``"0```````````````0`````````)@````<````"````
ME`$``)0!```@```````````````$`````````#0```#V__]O`@```+0!``"T
M`0``[`````4`````````!`````0````^````"P````(```"@`@``H`(``)`&
M```&`````P````0````0````1@````,````"````,`D``#`)``"Y!```````
M```````!`````````$X```#___]O`@```.H-``#J#0``T@````4`````````
M`@````(```!;````_O__;P(```"\#@``O`X``&`````&`````@````0`````
M````:@````D````"````'`\``!P/``#0````!0`````````$````"````',`
M```)````0@```.P/``#L#P``Z`$```4````5````!`````@```!\`````0``
M``8```#4$0``U!$```P```````````````0`````````=P````$````&````
MX!$``.`1`````P`````````````$````!````((````!````!@```.`4``#@
M%```X"0`````````````"`````````"(`````0````8```#`.0``P#D```@`
M``````````````0`````````C@````$````"````R#D``,@Y``#X00``````
M```````$`````````)8````!``!P@@```,![``#`>P``"`````T`````````
M!`````````"A`````0````(```#(>P``R'L```0```````````````0`````
M````JP````X````#````O(T``+Q]```$```````````````$````!````+<`
M```/`````P```,"-``#`?0``!```````````````!`````0```##````!@``
M``,```#$C0``Q'T```@!```&``````````0````(````S`````$````#````
MS(X``,Q^```T`0`````````````$````!````-$````!`````P````"0````
M@```2```````````````!`````````#7````"`````,```!(D```2(```!0`
M``````````````0`````````W`````$````P`````````$B````>````````
M```````!`````0```.4````#``!P``````````!F@```,P``````````````
M`0`````````!`````P``````````````F8```/4```````````````$`````
#````
